<?php
include '../../includes/db.php';
include '../../includes/functions.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $token = sanitize_input($_POST['token']);
    $password = sanitize_input($_POST['password']);
    $confirm_password = sanitize_input($_POST['confirm_password']);

    if ($password !== $confirm_password) {
        $error_message = "Passwords do not match.";
    } else {
        // Check if token exists
        $stmt = $conn->prepare("SELECT * FROM admins WHERE reset_token = ?");
        $stmt->execute([$token]);
        $admin = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($admin) {
            // Update password
            $hashed_password = password_hash($password, PASSWORD_BCRYPT);
            $stmt = $conn->prepare("UPDATE admins SET password = ?, reset_token = NULL WHERE reset_token = ?");
            $stmt->execute([$hashed_password, $token]);

            $success_message = "Your password has been reset. You can now <a href='login.php'>login</a>.";
        } else {
            $error_message = "Invalid or expired token.";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>Admin Reset Password</title>
    <link href="../assets/css/bootstrap.min.css" rel="stylesheet">
    <link href="../assets/css/sb-admin-2.min.css" rel="stylesheet">
    <link href="../assets/css/custom.css" rel="stylesheet">
</head>
<body class="bg-gradient-primary">
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-xl-10 col-lg-12 col-md-9">
                <div class="card o-hidden border-0 shadow-lg my-5">
                    <div class="card-body p-0">
                        <div class="row">
                            <div class="col-lg-6 d-none d-lg-block bg-password-image"></div>
                            <div class="col-lg-6">
                                <div class="p-5">
                                    <div class="text-center">
                                        <h1 class="h4 text-gray-900 mb-4">Reset Your Password</h1>
                                    </div>
                                    <?php if (isset($error_message)): ?>
                                        <div class="alert alert-danger"><?php echo htmlspecialchars($error_message); ?></div>
                                    <?php elseif (isset($success_message)): ?>
                                        <div class="alert alert-success"><?php echo htmlspecialchars($success_message); ?></div>
                                    <?php endif; ?>
                                    <form class="user" method="post" action="">
                                        <input type="hidden" name="token" value="<?php echo htmlspecialchars($_GET['token']); ?>">
                                        <div class="form-group">
                                            <input type="password" class="form-control form-control-user" name="password" placeholder="New Password" required>
                                        </div>
                                        <div class="form-group">
                                            <input type="password" class="form-control form-control-user" name="confirm_password" placeholder="Confirm Password" required>
                                        </div>
                                        <button type="submit" class="btn btn-primary btn-user btn-block">
                                            Reset Password
                                        </button>
                                    </form>
                                    <hr>
                                    <div class="text-center">
                                        <a class="small" href="login.php">Remembered your password? Login!</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <script src="../assets/js/jquery.min.js"></script>
    <script src="../assets/js/bootstrap.bundle.min.js"></script>
    <script src="../assets/js/sb-admin-2.min.js"></script>
    <script src="../assets/js/custom.js"></script>
</body>
</html>
