<?php

function getBunnyApiKey() {
    // Fetch your API key from the database or configuration
    global $conn;
    $stmt = $conn->prepare("SELECT value FROM api WHERE name = 'bunnycdn_api_key'");
    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    return $result['value'];
}

function createBunnyCdnPullZone($zoneName, $originUrl) {
    $apiKey = getBunnyApiKey();
    $url = "https://bunnycdn.com/api/pullzone";

    $data = [
        'Name' => $zoneName,
        'OriginUrl' => $originUrl
    ];

    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Content-Type: application/json',
        "AccessKey: $apiKey"
    ]);

    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($httpCode != 201) {
        return [
            'error' => "Failed to create BunnyCDN pull zone.",
            'response' => $response,
            'httpCode' => $httpCode
        ];
    }

    return json_decode($response, true);
}

function deleteBunnyCdnPullZone($zoneId) {
    $apiKey = getBunnyApiKey();
    $url = "https://bunnycdn.com/api/pullzone/$zoneId";

    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "DELETE");
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "AccessKey: $apiKey"
    ]);

    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($httpCode != 204) {
        return [
            'error' => "Failed to delete BunnyCDN pull zone.",
            'response' => $response,
            'httpCode' => $httpCode
        ];
    }

    return [
        'success' => true
    ];
}

function getBunnyCdnPullZoneDetails($zoneId) {
    $apiKey = getBunnyApiKey();
    $url = "https://bunnycdn.com/api/pullzone/$zoneId";

    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "AccessKey: $apiKey"
    ]);

    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($httpCode != 200) {
        return [
            'error' => "Failed to retrieve BunnyCDN pull zone details.",
            'response' => $response,
            'httpCode' => $httpCode
        ];
    }

    return json_decode($response, true);
}

function purgeBunnyCdnCache($zoneId, $url = '') {
    $apiKey = getBunnyApiKey();
    $purgeUrl = "https://bunnycdn.com/api/pullzone/$zoneId/purgeCache";

    $data = [];
    if (!empty($url)) {
        $data['url'] = $url;
    }

    $ch = curl_init($purgeUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Content-Type: application/json',
        "AccessKey: $apiKey"
    ]);

    $response = curl_exec($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($httpCode != 200) {
        return [
            'error' => "Failed to purge BunnyCDN cache.",
            'response' => $response,
            'httpCode' => $httpCode
        ];
    }

    return [
        'success' => true
    ];
}
?>
