<?php
include('../../includes/db.php');
include('../../includes/functions.php');
include('../../includes/bunnycdn.php');
check_login();
check_user();

$user_id = $_SESSION['user_id'];

// Fetch user's current subscription
$stmt = $conn->prepare("SELECT subscriptions.*, packages.website_limit FROM subscriptions 
                        JOIN packages ON subscriptions.package_id = packages.id 
                        WHERE subscriptions.user_id = ? AND subscriptions.status = 'Active'");
$stmt->execute([$user_id]);
$subscription = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$subscription) {
    die('No active subscription found.');
}

$website_limit = $subscription['website_limit'];

// Fetch the number of websites user has already added
$stmt = $conn->prepare("SELECT COUNT(*) as website_count FROM cdn_websites WHERE user_id = ?");
$stmt->execute([$user_id]);
$website_count = $stmt->fetch(PDO::FETCH_ASSOC)['website_count'];

if ($website_limit != -1 && $website_count >= $website_limit) {
    die('You have reached your website limit.');
}

// Handle adding a new website
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (!empty($_POST['website_url'])) {
        $website_url = $_POST['website_url'];

        // Check if the website URL already exists
        $stmt = $conn->prepare("SELECT COUNT(*) as count FROM cdn_websites WHERE website_url = ?");
        $stmt->execute([$website_url]);
        $count = $stmt->fetch(PDO::FETCH_ASSOC)['count'];

        if ($count > 0) {
            $error_message = 'URL already exists either in this or another account. Please contact support for assistance.';
        } else {
            // Generate a unique zone name
            $zoneName = substr(md5(uniqid(rand(), true)), 0, 7);

            // Create the BunnyCDN pull zone
            $response = createBunnyCdnPullZone($zoneName, $website_url);

            if (isset($response['error'])) {
                $error_message = 'Failed to create BunnyCDN pull zone.';
            } else {
                $zoneId = $response['Id'];

                // Insert the new website into the cdn_websites table
                $stmt = $conn->prepare("INSERT INTO cdn_websites (user_id, website_url) VALUES (?, ?)");
                $stmt->execute([$user_id, $website_url]);
                $website_id = $conn->lastInsertId();

                // Insert the zone data into the cdn_zones table
                $stmt = $conn->prepare("INSERT INTO cdn_zones (user_id, website_id, zoneid, zone_name) VALUES (?, ?, ?, ?)");
                $stmt->execute([$user_id, $website_id, $zoneId, $zoneName]);

                header("Location: cdn.php?success=add");
                exit();
            }
        }
    } else {
        $error_message = 'Website URL is required.';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <title>Add Website</title>
    <link href="../../assets/css/bootstrap.min.css" rel="stylesheet">
    <link href="../../assets/css/sb-admin-2.min.css" rel="stylesheet">
</head>
<body id="page-top">
    <div id="wrapper">
        <?php include('../../includes/sidebar.php'); ?> <!-- Include sidebar -->

        <div id="content-wrapper" class="d-flex flex-column">
            <div id="content">
                <?php include('../../includes/topbar.php'); ?> <!-- Include topbar -->

                <div class="container-fluid">
                    <h1 class="h3 mb-4 text-gray-800">Add Website</h1>
                    <div class="card shadow mb-4">
                        <div class="card-header py-3">
                            <h6 class="m-0 font-weight-bold text-primary">Add a New Website</h6>
                        </div>
                        <div class="card-body">
                            <?php
                            if (isset($error_message)) {
                                echo '<div class="alert alert-danger">' . htmlspecialchars($error_message) . '</div>';
                            }
                            ?>
                            <form method="post" action="">
                                <div class="form-group">
                                    <label for="website_url">Website URL</label>
                                    <input type="url" class="form-control" id="website_url" name="website_url" required>
                                </div>
                                <button type="submit" class="btn btn-primary">Add Website</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>

            <?php include('../../includes/footer.php'); ?> <!-- Include footer -->
        </div>
    </div>

    <script src="../../assets/js/jquery.min.js"></script>
    <script src="../../assets/js/bootstrap.bundle.min.js"></script>
    <script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
