<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$user_id = $_SESSION['user_id'];

// Fetch user's current subscription
$stmt = $conn->prepare("SELECT subscriptions.*, packages.website_limit FROM subscriptions 
                        JOIN packages ON subscriptions.package_id = packages.id 
                        WHERE subscriptions.user_id = ? AND subscriptions.status = 'Active'");
$stmt->execute([$user_id]);
$subscription = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$subscription) {
    die('No active subscription found.');
}

$website_limit = $subscription['website_limit'];

// Fetch the number of websites user has already added
$stmt = $conn->prepare("SELECT COUNT(*) as website_count FROM cdn_websites WHERE user_id = ?");
$stmt->execute([$user_id]);
$website_count = $stmt->fetch(PDO::FETCH_ASSOC)['website_count'];

if ($website_limit != -1 && $website_count >= $website_limit) {
    die('You have reached your website limit.');
}

// Handle adding a new website
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (!empty($_POST['website_url'])) {
        $website_url = $_POST['website_url'];

        // Check if the URL already exists in the database
        $stmt = $conn->prepare("SELECT COUNT(*) AS url_count FROM cdn_websites WHERE website_url = ?");
        $stmt->execute([$website_url]);
        $url_count = $stmt->fetch(PDO::FETCH_ASSOC)['url_count'];

        if ($url_count > 0) {
            // URL already exists
            $error_message = 'URL already exists either in this or another account. Please contact support for assistance.';
            header("Location: cdn.php?error=url_exists");
            exit();
        } else {
            // Insert the new website into the cdn_websites table
            $stmt = $conn->prepare("INSERT INTO cdn_websites (user_id, website_url, created_date, status) VALUES (?, ?, NOW(), 'Active')");
            $stmt->execute([$user_id, $website_url]);

            header("Location: cdn.php?success=add");
            exit();
        }
    } else {
        $error_message = 'Website URL is required.';
        header("Location: cdn.php?error=1");
        exit();
    }
}
?>
