<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$pageTitle = "CDN Management";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');

// Fetch user's current subscription
$user_id = $_SESSION['user_id'];
$stmt = $conn->prepare("SELECT subscriptions.*, packages.website_limit FROM subscriptions 
                        JOIN packages ON subscriptions.package_id = packages.id 
                        WHERE subscriptions.user_id = ? AND subscriptions.status = 'Active'");
$stmt->execute([$user_id]);
$subscription = $stmt->fetch(PDO::FETCH_ASSOC);

$website_limit = $subscription['website_limit'] ?? 0;
$subscription_status = $subscription ? $subscription['status'] : 'Inactive';

// Fetch the number of websites user has already added
$stmt = $conn->prepare("SELECT COUNT(*) as website_count FROM cdn_websites WHERE user_id = ?");
$stmt->execute([$user_id]);
$website_count = $stmt->fetch(PDO::FETCH_ASSOC)['website_count'];

// Fetch CDN data from the database for the logged-in user
$stmt = $conn->prepare("SELECT * FROM cdn_websites WHERE user_id = ?");
$stmt->execute([$user_id]);
$cdns = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Fetch hostname_url from the API settings
$stmt = $conn->prepare("SELECT value FROM api WHERE name = 'hostname_url'");
$stmt->execute();
$hostname_url = $stmt->fetch(PDO::FETCH_ASSOC)['value'];
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">CDN Management</h1>
            <div class="mb-4">
                <button class="btn btn-primary" data-toggle="modal" data-target="#addWebsiteModal">Add Website</button>
            </div>
            <?php if (isset($_GET['success']) && $_GET['success'] == 'add'): ?>
                <div class="alert alert-success">Website added successfully!</div>
            <?php elseif (isset($_GET['success']) && $_GET['success'] == 'delete'): ?>
                <div class="alert alert-success">Website deleted successfully!</div>
            <?php elseif (isset($_GET['error']) && $_GET['error'] == 1): ?>
                <div class="alert alert-danger">An error occurred. Please try again.</div>
            <?php elseif (isset($_GET['error']) && $_GET['error'] == 'url_exists'): ?>
                <div class="alert alert-danger">URL already exists either in this or another account. Please contact support for assistance.</div>
            <?php endif; ?>
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">CDN List</h6>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-bordered" id="dataTable" width="100%" cellspacing="0">
                            <thead>
                                <tr>
                                    <th>SL</th>
                                    <th>Website URL</th>
                                    <th>Created Date</th>
                                    <th>CDN URL</th>
                                    <th>Status</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                $serialNumber = 1;
                                foreach ($cdns as $cdn) {
                                    $created_date = isset($cdn['created_date']) ? date('d-M-Y', strtotime($cdn['created_date'])) : 'N/A';
                                    $cdn_url = $hostname_url;  // Only use hostname_url as per the requirement
                                    $status = ($subscription_status === 'Active') ? 'Active' : 'Inactive';
                                    $status_class = ($status === 'Active') ? 'text-success font-weight-bold' : 'text-danger font-weight-bold';

                                    echo "<tr>";
                                    echo "<td>" . $serialNumber++ . "</td>";
                                    echo "<td><a href='" . htmlspecialchars($cdn['website_url']) . "' target='_blank' class='text-decoration-none'>" . htmlspecialchars($cdn['website_url']) . "</a></td>";
                                    echo "<td>" . $created_date . "</td>";
                                    echo "<td>
                                            <span>" . htmlspecialchars($cdn_url) . "</span>
                                            <button class='btn btn-secondary btn-sm ml-2 copy-btn' data-clipboard-text='" . htmlspecialchars($cdn_url) . "'>
                                                <i class='fas fa-copy'></i>
                                            </button>
                                          </td>";
                                    echo "<td class='$status_class'>" . $status . "</td>";
                                    echo "<td>
                                            <button class='btn btn-warning btn-sm purge-btn' data-id='" . $cdn['id'] . "'>Purge Cache</button>
                                            <button class='btn btn-info btn-sm details-btn' data-id='" . $cdn['id'] . "'>Details</button>
                                            <button class='btn btn-danger btn-sm delete-btn' data-id='" . $cdn['id'] . "' data-toggle='modal' data-target='#deleteModal'>Delete</button>
                                          </td>";
                                    echo "</tr>";
                                }
                                ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<!-- Add Website Modal -->
<div class="modal fade" id="addWebsiteModal" tabindex="-1" role="dialog" aria-labelledby="addWebsiteModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <?php if (!$subscription): ?>
                <div class="modal-header">
                    <h5 class="modal-title" id="addWebsiteModalLabel">Subscription Required</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <p>You need to have an active subscription to add a website. Please visit the <a href="packages.php">Packages</a> page to buy a package.</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                </div>
            <?php elseif ($website_limit != -1 && $website_count >= $website_limit): ?>
                <div class="modal-header">
                    <h5 class="modal-title" id="addWebsiteModalLabel">Upgrade Plan</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <p>You have reached your website limit. Please visit the <a href="packages.php">Packages</a> page to upgrade your plan.</p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                </div>
            <?php else: ?>
                <form method="post" action="add_website.php">
                    <div class="modal-header">
                        <h5 class="modal-title" id="addWebsiteModalLabel">Add Website</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <div class="form-group">
                            <label for="website_url">Website URL</label>
                            <input type="url" class="form-control" id="website_url" name="website_url" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Add Website</button>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- Delete Confirmation Modal -->
<div class="modal fade" id="deleteModal" tabindex="-1" role="dialog" aria-labelledby="deleteModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <form method="post" action="delete_website.php">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteModalLabel">Delete Confirmation</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    Are you sure you want to delete this CDN?
                    <input type="hidden" id="delete-id" name="id" value="">
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancel</button>
                    <button type="submit" class="btn btn-danger">Delete</button>
                </div>
            </form>
                </div>
            </form>
        </div>
    </div>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/clipboard@2.0.6/dist/clipboard.min.js"></script>
<script>
    new ClipboardJS('.copy-btn');

    $('.delete-btn').click(function() {
        var id = $(this).data('id');
        $('#delete-id').val(id);
    });

    $('.purge-btn').click(function() {
        var id = $(this).data('id');
        // Add your purge cache logic here
        alert('Purge cache for CDN with ID: ' + id);
    });

    $('.details-btn').click(function() {
        var id = $(this).data('id');
        // Add your details logic here
        alert('Details for CDN with ID: ' + id);
    });
</script>
</body>
</html>
