<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

if (!isset($_SESSION['payment_data'])) {
    header("Location: packages.php");
    exit();
}

$payment_data = $_SESSION['payment_data'];
$user_id = $payment_data['user_id'];
$package_id = $payment_data['package_id'];
$gateway_name = $payment_data['gateway_name'];
$package_price = $payment_data['package_price'];
$package_name = $payment_data['package_name'];
$billing_cycle = $payment_data['package_billing_cycle'];

// Calculate start and end dates
$start_date = date('Y-m-d H:i:s');
$end_date = $billing_cycle == 'yearly' ? date('Y-m-d H:i:s', strtotime('+1 year')) : date('Y-m-d H:i:s', strtotime('+1 month'));

// Remove payment_data from session to avoid reuse
unset($_SESSION['payment_data']);

function generateUniqueID($length = 7) {
    $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, $charactersLength - 1)];
    }
    return '#' . $randomString; // Prefix with #
}

try {
    $conn->beginTransaction();

    // Check if the user already has an active subscription
    $stmt = $conn->prepare("SELECT id FROM subscriptions WHERE user_id = ? AND status = 'Active'");
    $stmt->execute([$user_id]);
    $existing_subscription = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($existing_subscription) {
        // Update existing subscription
        $subscription_id = $existing_subscription['id'];
        $stmt = $conn->prepare("UPDATE subscriptions SET package_id = ?, billing_cycle = ?, start_date = ?, end_date = ?, updated_at = NOW() WHERE id = ?");
        $stmt->execute([$package_id, $billing_cycle, $start_date, $end_date, $subscription_id]);
    } else {
        // Insert new subscription record
        $stmt = $conn->prepare("INSERT INTO subscriptions (user_id, package_id, status, billing_cycle, start_date, end_date, created_at) VALUES (?, ?, 'Active', ?, ?, ?, NOW())");
        $stmt->execute([$user_id, $package_id, $billing_cycle, $start_date, $end_date]);
        $subscription_id = $conn->lastInsertId();
    }

    // Generate a unique invoice ID
    $invoice_id = generateUniqueID();

    // Insert invoice record
    $stmt = $conn->prepare("INSERT INTO invoices (id, user_id, subscription_id, package_id, amount, gateway_name, status, created_at) VALUES (?, ?, ?, ?, ?, ?, 'Paid', NOW())");
    $stmt->execute([$invoice_id, $user_id, $subscription_id, $package_id, $package_price, $gateway_name]);

    $conn->commit();
    header("Location: subscriptions.php");
} catch (Exception $e) {
    $conn->rollBack();
    throw $e;
}
?>
