<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

if (isset($_GET['paymentId']) && isset($_GET['PayerID'])) {
    $payment_id = $_GET['paymentId'];
    $payer_id = $_GET['PayerID'];

    $credentials = getPayPalCredentials($conn);
    $client_id = $credentials['api_key'];
    $client_secret = $credentials['api_secret'];

    // Execute payment
    $execute_url = "https://api.sandbox.paypal.com/v1/payments/payment/$payment_id/execute";
    $execute_data = [
        'payer_id' => $payer_id
    ];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $execute_url);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        'Content-Type: application/json',
        'Authorization: Basic ' . base64_encode($client_id . ':' . $client_secret)
    ]);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($execute_data));
    $response = curl_exec($ch);
    curl_close($ch);

    $response_data = json_decode($response, true);

    if (isset($response_data['error'])) {
        die('Error: ' . $response_data['error_description']);
    }

    // Handle payment success
    if ($response_data['state'] == 'approved') {
        // Retrieve payment data from session
        $payment_data = $_SESSION['payment_data'];
        $user_id = $payment_data['user_id'];
        $package_id = $payment_data['package_id'];
        $package_price = $payment_data['package_price'];
        $gateway_name = $payment_data['gateway_name'];
        $billing_cycle = $payment_data['package_billing_cycle'];

        // Calculate start and end dates
        $start_date = date('Y-m-d H:i:s');
        $end_date = $billing_cycle == 'yearly' ? date('Y-m-d H:i:s', strtotime('+1 year')) : date('Y-m-d H:i:s', strtotime('+1 month'));

        try {
            $conn->beginTransaction();

            // Check if the user already has an active subscription
            $stmt = $conn->prepare("SELECT id FROM subscriptions WHERE user_id = ? AND status = 'Active'");
            $stmt->execute([$user_id]);
            $existing_subscription = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($existing_subscription) {
                // Update existing subscription
                $subscription_id = $existing_subscription['id'];
                $stmt = $conn->prepare("UPDATE subscriptions SET package_id = ?, billing_cycle = ?, start_date = ?, end_date = ?, updated_at = NOW() WHERE id = ?");
                $stmt->execute([$package_id, $billing_cycle, $start_date, $end_date, $subscription_id]);
            } else {
                // Insert new subscription record
                $stmt = $conn->prepare("INSERT INTO subscriptions (user_id, package_id, status, billing_cycle, start_date, end_date, created_at) VALUES (?, ?, 'Active', ?, ?, ?, NOW())");
                $stmt->execute([$user_id, $package_id, $billing_cycle, $start_date, $end_date]);
                $subscription_id = $conn->lastInsertId();
            }

            // Generate a unique invoice ID
            $invoice_id = generateUniqueID();

            // Insert invoice record
            $stmt = $conn->prepare("INSERT INTO invoices (id, user_id, subscription_id, package_id, amount, gateway_name, status, created_at) VALUES (?, ?, ?, ?, ?, ?, 'Paid', NOW())");
            $stmt->execute([$invoice_id, $user_id, $subscription_id, $package_id, $package_price, $gateway_name]);

            $conn->commit();
            header("Location: subscriptions.php");
        } catch (Exception $e) {
            $conn->rollBack();
            throw $e;
        }
    } else {
        header("Location: paypal_cancel.php");
    }
} else {
    header("Location: packages.php");
}
?>
