<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

// Fetch user details
$user_id = $_SESSION['user_id'];
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->execute([$user_id]);
$user = $stmt->fetch();

$error_message = "";
$success_message = "";

// Handle form submission for profile update
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['update_profile'])) {
        $name = sanitize_input($_POST['name']);
        $email = sanitize_input($_POST['email']);

        // Update user details
        $stmt = $conn->prepare("UPDATE users SET name = ?, email = ? WHERE id = ?");
        try {
            $stmt->execute([$name, $email, $user_id]);
            $_SESSION['name'] = $name;
            $success_message = "Profile updated successfully.";
        } catch (PDOException $e) {
            $error_message = "Database error: " . $e->getMessage();
        }
    }

    // Handle form submission for password update
    if (isset($_POST['update_password'])) {
        $new_password = sanitize_input($_POST['new_password']);
        $repeat_password = sanitize_input($_POST['repeat_password']);

        if ($new_password !== $repeat_password) {
            $error_message = "New passwords do not match.";
        } else {
            $hashed_password = password_hash($new_password, PASSWORD_BCRYPT);
            $stmt = $conn->prepare("UPDATE users SET password = ? WHERE id = ?");
            try {
                $stmt->execute([$hashed_password, $user_id]);
                $success_message = "Password updated successfully.";
            } catch (PDOException $e) {
                $error_message = "Database error: " . $e->getMessage();
            }
        }
    }
}

// Get Gravatar URL
$email_hash = md5(strtolower(trim($user['email'])));
$gravatar_url = "https://www.gravatar.com/avatar/$email_hash?s=200&d=404";
if (@get_headers($gravatar_url)[0] == 'HTTP/1.1 404 Not Found') {
    $gravatar_url = "https://www.gravatar.com/avatar/?d=mp&s=200";
}

$pageTitle = "Profile";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');
?>

<div class="container-fluid">
    <h1 class="h3 mb-4 text-gray-800">Profile</h1>
    <div class="row">
        <div class="col-lg-8">
            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger" role="alert">
                    <?php echo $error_message; ?>
                </div>
            <?php elseif (!empty($success_message)): ?>
                <div class="alert alert-success" role="alert">
                    <?php echo $success_message; ?>
                </div>
            <?php endif; ?>
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Profile Settings</h6>
                </div>
                <div class="card-body">
                    <form method="post" action="profile.php">
                        <div class="form-group">
                            <label for="name">Name</label>
                            <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($user['name']); ?>" required>
                        </div>
                        <div class="form-group">
                            <label for="email">Email</label>
                            <input type="email" class="form-control" id="email" name="email" value="<?php echo htmlspecialchars($user['email']); ?>" required>
                        </div>
                        <button type="submit" name="update_profile" class="btn btn-primary">Update Profile</button>
                    </form>
                    <hr>
                    <form method="post" action="profile.php">
                        <div class="form-group">
                            <label for="new_password">New Password</label>
                            <input type="password" class="form-control" id="new_password" name="new_password" required>
                        </div>
                        <div class="form-group">
                            <label for="repeat_password">Repeat New Password</label>
                            <input type="password" class="form-control" id="repeat_password" name="repeat_password" required>
                        </div>
                        <button type="submit" name="update_password" class="btn btn-primary">Update Password</button>
                    </form>
                </div>
            </div>
        </div>
        <div class="col-lg-4 text-center">
            <img src="<?php echo $gravatar_url; ?>" alt="Profile Image" class="img-fluid rounded-circle">
            <p class="mt-3">This is your profile image from <a href="https://gravatar.com" target="_blank">Gravatar</a>.</p>
        </div>
    </div>
</div>

<?php
include('../../includes/footer.php');
?>
